function [Sixidx2]=Sixidx_given_clabel(elorig,origclab,origcidx)
%input an edge list of a non-planar graph, and a Clabel/Cidx.
%this function computes a planar drawing of the planarization of the graph
%with crossings on the specified edges.

%OPTIONS: 0 - Check planarity using Boyer Myrviold planarity check from
%boost graph library.
% 1 - Check planarity using Melhorn/Mutzel's implementation of Hopfcroft Tarjan planarity check.
% 2 - Option 1, with the addition of computing a Sixidx
% representation of the embedding computed by option 1, for each
% maximal two connected component of the input graph.
Sixidx2=[];
size(elorig)
origcidx(end)
M=size(elorig,1);
Mb=M;
N=max(max(elorig));
finClab1 = zeros(M,1);
fincCcnt = zeros(M,1);
finCidx1 = zeros(M,1);
Final_crossings=0;
fcnt=0;

%check for multi edge crossings.  If they exist, return error and user
%needs to subdivide these edges.
for i=1:M
    for j=origcidx(i)+1:origcidx(i+1)
        for k=j+1:origcidx(i+1)
            if origclab(j)==origclab(k)
                disp('multi-edge crossings exist, these edges need subdivided in order to solve.');
                return;
            end
        end
    end
end


einvmap1=1:M;
vinvmap1=1:N;
el=elorig;
checkdel=1;
while checkdel
    checkdel=0;
    deg=zeros(N,1);
    for i=1:M
        deg(el(i,1))=deg(el(i,1))+1;
        deg(el(i,2))=deg(el(i,2))+1;
    end
    dele=0;
    delv=0;
    for i=1:M
        if deg(el(i,1))==1
            dele=i;
            delv=el(i,1);
            break;
        elseif deg(el(i,2))==1
            dele=i;
            delv=el(i,2);
            break
        end
    end
    if dele>0
        checkdel=1;
        el(dele)=[];
        vinvmap1(delv)=[];
        einvmap1(dele)=[];
        M=M-1;
        N=N-1;
        for j=1:M
            if el(i,1)>delv
                el(i,1)=el(i,1)-1;
            end
            if el(i,2)>delv
                el(i,2)=el(i,2)-1;
            end
        end
    end
end
emap1=zeros(Mb,1);
for i=1:M
    emap1(einvmap1(i))=i;
end
%new clabs
cnt=0;
clabtmp1=zeros(origcidx(Mb+1),1);
clabtmp2=zeros(origcidx(Mb+1),1);
cidxtmp=zeros(Mb,1);
for i=1:Mb
    if emap1(i)>0
        for j=origcidx(i)+1:origcidx(i+1)
            if emap1(origclab(j))>0
                cnt=cnt+1;
                cidxtmp(emap1(i))=cidxtmp(emap1(i))+1;
                clabtmp1(cnt)=emap1(i);
                clabtmp2(cnt)=emap1(origclab(j));
            end
        end
    end
end
origcidx=zeros(M+1,1);
origlab=zeros(origcidx(Mb+1),1);
for i=1:M
    origcidx(i+1)=origcidx(i)+cidxtmp(i);
end
cidxfill=zeros(M,1);
for i=1:cnt
    cidxfill(clabtmp1(i))=cidxfill(clabtmp1(i))+1;
    cidxfill(clabtmp2(i))=cidxfill(clabtmp2(i))+1;
    origlab(origcidx(clabtmp1(i))+cidxfill(clabtmp1(i)))=clabtmp2(cnt);
    origlab(origcidx(clabtmp2(i))+cidxfill(clabtmp2(i)))=clabtmp1(cnt);
end
for i=1:M
    if origcidx(i+1)-origcidx(i)>0
        if vinvmap1(el(i,1))>vinvmap1(el(i,2)) %then clabs need swapped
            origlab(origcidx(i)+1:origcidx(i+1))=origlab(origcidx(i+1):-1:origcidx(i)+1);
        end
    end
end
eldel1=el;
%now el,origclab,origcidx,N,M are all after del1 and invmaps go to orig
%labels.
Mdel1=M;
Ndel1=N;
ccross=origcidx(Mdel1+1)/2;
planvlabels=zeros(origcidx(M+1),1);
planedges=zeros(origcidx(M+1),1);
elistorig=zeros(M+origcidx(M+1),1);
eidxorig=[0;(1:M)']+origcidx;
elistorig(eidxorig(1:M)+1)=1:M;
origedgelabel=[(1:M)';zeros(origcidx(end),1)];
origedgeorder=[ones(M,1);zeros(origcidx(end),1)];
el=[elorig;zeros(origcidx(end),2)];
for i=1:M
    if origcidx(i+1)-origcidx(i)~=0
        tt=el(i,2);
    end
    for j=1:origcidx(i+1)-origcidx(i)
        M=M+1;
        elistorig(eidxorig(i)+j+1)=M;
        origedgelabel(M)=i;
        origedgeorder(M)=j+1;
        if planvlabels(origcidx(i)+j)==0
            N=N+1;
            planvlabels(origcidx(i)+j)=N;
            ce=origclab(origcidx(i)+j);
            f1=find(origclab(origcidx(ce)+1:origcidx(ce+1))==i);
            planvlabels(origcidx(ce)+f1)=N;
            planedges(N-Ndel1)=i;
            planedges(N-Ndel1+ccross)=origclab(origcidx(i)+j);
        end
    end
    if origcidx(i+1)-origcidx(i)>0
        el(M,1:2)=[tt,planvlabels(origcidx(i+1))];
        el(i,2)=planvlabels(origcidx(i)+1);
    end
    for j=1:origcidx(i+1)-origcidx(i)-1
        if planvlabels(origcidx(i)+j)<planvlabels(origcidx(i)+j+1)
            el(elistorig(eidxorig(i)+j+1),1)=planvlabels(origcidx(i)+j);
            el(elistorig(eidxorig(i)+j+1),2)=planvlabels(origcidx(i)+j+1);
        else
            el(elistorig(eidxorig(i)+j+1),1)=planvlabels(origcidx(i)+j+1);
            el(elistorig(eidxorig(i)+j+1),2)=planvlabels(origcidx(i)+j);
        end
    end
end
%now N,M,el are for the planarized G.
incidentetotal=zeros(N,1);
Sixidxtotal=[el,zeros(M,4)];
deg=zeros(N,1);
vadj=zeros(2*M,1);
eadj=zeros(2*M,1);
vidx=zeros(N+1,1);
for i=1:M
    deg(el(i,1))=deg(el(i,1))+1;
    deg(el(i,2))=deg(el(i,2))+1;
end
for i=1:N
    vidx(i+1)=vidx(i)+deg(i);
end
degidx = zeros(N,1);
for i=1:M
    v1 = el(i,1);
    v2 = el(i,2);
    degidx(v1)=degidx(v1)+1;
    degidx(v2)=degidx(v2)+1;
    vadj(vidx(v1)+degidx(v1))=v2;
    vadj(vidx(v2)+degidx(v2))=v1;
    eadj(vidx(v1)+degidx(v1))=i;
    eadj(vidx(v2)+degidx(v2))=i;
end
Mplan=M;
M2=M;
%find connected components
ccnt=0;
ctcnt=0;
ccidx=0;
clst=[];
visited=zeros(N,1);
for i=1:N
    if visited(i)==0
        ctcnt=ctcnt+1;
        ccnt=ccnt+1;
        clst(ccnt)=i;
        stack=zeros(N,1);
        stackpos=0;
        stackmax=1;
        stack(1)=i;
        visited(i)=1;
        while stackpos<stackmax
            stackpos=stackpos+1;
            currv=stack(stackpos);
            for j=vidx(currv)+1:vidx(currv+1)
                if visited(vadj(j))==0
                    visited(vadj(j))=1;
                    ccnt=ccnt+1;
                    clst(ccnt)=vadj(j);
                    stackmax=stackmax+1;
                    stack(stackmax)=vadj(j);
                end
            end
        end
        ccidx(ctcnt+1)=ccnt;
    end
end
%for each connected component find maximal two connected components
Mextended=M;
for z=1:ctcnt
    if ccidx(z+1)-ccidx(z)<5
        continue;
    end
    %build component el
    currN=ccidx(z+1)-ccidx(z);
    visited=zeros(currN,1);
    LP=zeros(currN,1);
    vinvmapcomp=clst(ccidx(z)+1:ccidx(z+1));
    einvmapcomp=zeros(M,1);
    vmapcomp=zeros(N,1);
    for i=1:currN
        vmapcomp(vinvmapcomp(i))=i;
    end
        
%     emapcomp=zeros(M,1);
    currdeg=zeros(currN,1);
    currvadj=zeros(2*M,1);
    curreadj=zeros(2*M,1);
    currM=0;
    currvidx=zeros(currN+1,1);
    elcomp=zeros(M,2);
    for i=1:currN
        vert=vinvmapcomp(i);
        for j=vidx(vert)+1:vidx(vert+1)
            %these edges will be in current component
            if vert<vadj(j)
                currM=currM+1;
                if i<vmapcomp(vadj(j))
                    elcomp(currM,[1 2])=[i,vmapcomp(vadj(j))];
                else
                    elcomp(currM,[2 1])=[i,vmapcomp(vadj(j))];
                end
                einvmapcomp(currM)=eadj(j);
%                 emapcomp(eadj(j))=currM;
                currdeg(i)=currdeg(i)+1;
                currdeg(vmapcomp(vadj(j)))=currdeg(vmapcomp(vadj(j)))+1;
            end
        end
    end
    for i=1:currN
        currvidx(i+1)=currvidx(i)+currdeg(i);
    end
    degidx = zeros(currN,1);
    for i=1:currM
        v1 = elcomp(i,1);
        v2 = elcomp(i,2);
        degidx(v1)=degidx(v1)+1;
        degidx(v2)=degidx(v2)+1;
        currvadj(currvidx(v1)+degidx(v1))=v2;
        currvadj(currvidx(v2)+degidx(v2))=v1;
        curreadj(currvidx(v1)+degidx(v1))=i;
        curreadj(currvidx(v2)+degidx(v2))=i;
    end
    currvadj2=currvadj;
    curreadj2=curreadj;
    currvidx2=currvidx;
    elcomp=elcomp(1:currM,:);
    elcomp2=elcomp;
    
    Tcheck=zeros(currM,1);
    T=zeros(currM,1);
    tcount=0;
    p=zeros(currN,1);
    clst2=zeros(2*currN,1);
    ccidx2=zeros(currN,1);
    ccnt=0;
    acompcnt=0;
    ecnt = 0;
    elst = zeros(currM,1);
    eidx = zeros(currM,1);
    artverts=[];
    M2=currM;
    %find maximal two connected components withing this connected
    %component and convert it into a biconnected graph.
%     curreadj2
%     pause
    [~,~,~,~,~,~,~,clst2,~,ccidx2,acompcnt,~,elst,eidx,artverts,M2,currvadj2,currvidx2,elcomp2,curreadj2] = UDFS5(1,1,visited,LP,Tcheck,T,tcount,p,elcomp,currvidx,currvadj,clst2,ccnt,curreadj,currN,ccidx2,acompcnt,ecnt,elst,eidx,artverts,M2,currvadj2,currvidx2,elcomp2,curreadj2);
    qq=sort(vinvmapcomp(elcomp2(currM+1:M2,[1,2])),2);
    Sixidxtotal=[Sixidxtotal;qq,zeros(M2-currM,4)];
    %remove all crossing verts which are also articulation vertices from
    %clab as they do not effect crossing number.
    for i=1:numel(artverts)
        if vinvmapcomp(artverts(i))>Ndel1 %then this crossing can be removed
            e1=planedges(vinvmapcomp(artverts(i))-Ndel1);
            e2=planedges(vinvmapcomp(artverts(i))-Ndel1+ccross);
            for j=origcidx(e1)+1:origcidx(e1+1)
                if planvlabels(j)==vinvmapcomp(artverts(i))
                    origclab(j)=[];
                    planvlabels(j)=[];
                    origcidx(e1+1:Mdel1+1)=origcidx(e1+1:Mdel1+1)-1;
                    break;
                end
            end
            for j=origcidx(e2)+1:origcidx(e2+1)
                if planvlabels(j)==vinvmapcomp(artverts(i))
                    origclab(j)=[];
                    planvlabels(j)=[];
                    origcidx(e2+1:Mdel1+1)=origcidx(e2+1:Mdel1+1)-1;
                    break;
                end
            end
        end
    end
    currdeg2=zeros(currN,1);
    for i=1:currN
        for j=currvidx2(i)+1:currvidx2(i+1)
            currdeg2(i)=currdeg2(i)+1;
        end
    end
    
    %now this component is biconnected and planar.
    vmapdfs=zeros(currN,1);
    LP=zeros(currN,1);
    p=zeros(currN,1);
    lowpt2=zeros(currN,1);
    backedge=zeros(M2,1);
%     curreadj2
    [vmapdfs,LP,~,p,~,lowpt2,backedge] = DFSrelabel4(1,1,vmapdfs,LP,p,currvidx2,currvadj2,currN,1,lowpt2,backedge,curreadj2);
%     backedge
% pause
    newel=vmapdfs(elcomp2);
    newel = sort(newel,2);
    buckets=zeros(2*currN,1);
    bucketcnt=zeros(2*currN,1);
    p2=zeros(currN,1);
    LP2=zeros(currN,1);
    lowpt22=zeros(currN,1);
    invvmapdfs=zeros(currN,1);
    for j=1:currN
        if j~=1
            p2(vmapdfs(j)) =  vmapdfs(p(j));
        end
        LP2(vmapdfs(j))=LP(j);
        lowpt22(vmapdfs(j)) = lowpt2(j);
        invvmapdfs(vmapdfs(j)) = j;
    end
    p=p2;
    lowpt2=lowpt22;
    LP=LP2;
    for j=1:M2
        if backedge(j)
            c=2*newel(j,1);
        else
            if p(newel(j,1))==newel(j,2)
                %then e=(v,w)=( el(i,2),el(i,1) )
                if lowpt2(newel(j,1))>=newel(j,2)
                    c=2*LP(newel(j,1));
                else
                    c=2*LP(newel(j,1))+1;
                end
            else
                if lowpt2(newel(j,2))>=newel(j,1)
                    c=2*LP(newel(j,2));
                else
                    c=2*LP(newel(j,2))+1;
                end
            end
        end
        bucketcnt(c)=bucketcnt(c)+1;
        buckets(c,bucketcnt(c))=j;
    end
    maxdeg=max(currdeg); %wrong here because of extra edges but will do for now
    neweadj=zeros(currN,maxdeg);
    newvadj=zeros(currN,maxdeg);
    newdeg=zeros(currN,1);
    for j=1:2*currN
        for k=1:bucketcnt(j)
            e=newel(buckets(j,k),[1,2]);
            if backedge(buckets(j,k))
                e=e([2,1]);
            end
            newdeg(e(1))=newdeg(e(1))+1;
            neweadj(e(1),newdeg(e(1)))=buckets(j,k);
            newvadj(e(1),newdeg(e(1)))=e(2);
        end
    end
    alpha=zeros(M2,1);

% pause

    [EL,L,lcnt,planar,alpha] = Strongly_planar4(1,backedge,p2,neweadj,newvadj,newel,M2,currN,newdeg,LP2,1,alpha);
    if planar==0
        disp('planar error1');
        return;
    end
    
        incidente=zeros(currN,1);
        for j=1:currM  %do not include extra edges here.
            if incidente(elcomp2(j,1))==0
                incidente(elcomp2(j,1))=j;
            end
            if incidente(elcomp2(j,2))==0
                incidente(elcomp2(j,2))=j;
            end
        end
        cyclic_adj=zeros(currN,max(newdeg));
        [T,~,cyclic_adj] = embedding_given_alpha4(1,1,alpha,cyclic_adj,newvadj,neweadj,M2,newdeg,p2,backedge,newel);

        currv = 2;
        curre = 1;
        scnt = 0;
        for j=1:M2
            if backedge(curre)==1
                break;
            end
            scnt = scnt + 1;
            curre = neweadj(currv,1);
            currv = newvadj(currv,1);
        end
        cyclic_adj(1,1:numel(T)+1) = [curre,T];
        %join to current Sixidx.
        Sixidx=[elcomp2,zeros(M2,4)];
        for j=1:currN
            for k=1:currdeg2(invvmapdfs(j))
                ec=cyclic_adj(j,k);
                if k==1
                    eb = cyclic_adj(j,currdeg2(invvmapdfs(j)));
                else
                    eb = cyclic_adj(j,k-1);
                end
                if k==currdeg2(invvmapdfs(j))
                    ef = cyclic_adj(j,1);
                else
                    ef = cyclic_adj(j,k+1);
                end
                if invvmapdfs(j)==elcomp2(ec,1)
                    %then i is smaller
                    Sixidx(ec,3) = ef;
                    Sixidx(ec,4) = eb;
                else
                    Sixidx(ec,5) = ef;
                    Sixidx(ec,6) = eb;
                end
            end
        end

        einvmapcomp=[einvmapcomp(1:currM);(Mextended+1:Mextended+(M2-currM))'];
        Mextended=Mextended+(M2-currM);
        %we now have the sixidx of the maximal two connected component and will attach
        %this to the sixidx for the whole planarised G (without the pendant verts).
        for j=1:currN
            currv=vinvmapcomp(invvmapdfs(j));
            %no entries on current vertex, so add those in Sixidx
            %and update incidentetotal
            enew=incidente(invvmapdfs(j)); %these do not have the extra edges in them.
            estart=enew;
            enewmapped=einvmapcomp(enew);
            incidentetotal(currv)=enewmapped;
            if vinvmapcomp(elcomp2(enew,1))<vinvmapcomp(elcomp2(enew,2))
                Sixidxtotal(enewmapped,3:6)=einvmapcomp(Sixidx(enew,3:6));
            else
                Sixidxtotal(enewmapped,[3,4])=einvmapcomp(Sixidx(enew,[5,6]));
                Sixidxtotal(enewmapped,[5,6])=einvmapcomp(Sixidx(enew,[3,4]));
            end
            if Sixidx(enew,1)==invvmapdfs(j)
                enew=Sixidx(enew,3);
            else
                enew=Sixidx(enew,5);
            end
            enewmapped=einvmapcomp(enew);
            for k=1:N
                if enew==estart
                    break;
                end
                if vinvmapcomp(elcomp2(enew,1))<vinvmapcomp(elcomp2(enew,2))
                    Sixidxtotal(enewmapped,3:6)=einvmapcomp(Sixidx(enew,3:6));
                else
                    Sixidxtotal(enewmapped,[3,4])=einvmapcomp(Sixidx(enew,[5,6]));
                    Sixidxtotal(enewmapped,[5,6])=einvmapcomp(Sixidx(enew,[3,4]));
                end
                if Sixidx(enew,1)==invvmapdfs(j)
                    enew=Sixidx(enew,3);
                else
                    enew=Sixidx(enew,5);
                end
                enewmapped=einvmapcomp(enew);
            end
        end

end
% acompcnt
% Mplan
% M2
% artverts

%remove dummy edges
for i=M+1:Mextended
   %first vertex on edge i. 
   e1=Sixidxtotal(i,3);
   v1=Sixidxtotal(i,1);
   e2=Sixidxtotal(i,4);
   for j=1:N
       if e1<=Mplan
           break
       end
       if Sixidxtotal(e1,1)==v1
          e1=Sixidxtotal(e1,3);
       else
          e1=Sixidxtotal(e1,5); 
       end
   end
   for j=1:N
       if e2<=Mplan
           break
       end
       if Sixidxtotal(e2,1)==v1
          e2=Sixidxtotal(e2,4);
       else
          e2=Sixidxtotal(e2,6); 
       end
   end
   if Sixidxtotal(e1,1)==v1
       Sixidxtotal(e1,4)=e2;
   else
       Sixidxtotal(e1,6)=e2;
   end
   if Sixidxtotal(e2,1)==v1
       Sixidxtotal(e2,3)=e1;
   else
       Sixidxtotal(e2,5)=e1;
   end
   %second vert.
   e1=Sixidxtotal(i,5);
   v1=Sixidxtotal(i,2);
   e2=Sixidxtotal(i,6);
   for j=1:N
       if e1<=Mplan
           break
       end
       if Sixidxtotal(e1,1)==v1
          e1=Sixidxtotal(e1,3);
       else
          e1=Sixidxtotal(e1,5); 
       end
   end
   for j=1:N
       if e2<=Mplan
           break
       end
       if Sixidxtotal(e2,1)==v1
          e2=Sixidxtotal(e2,4);
       else
          e2=Sixidxtotal(e2,6); 
       end
   end
   if Sixidxtotal(e1,1)==v1
       Sixidxtotal(e1,4)=e2;
   else
       Sixidxtotal(e1,6)=e2;
   end
   if Sixidxtotal(e2,1)==v1
       Sixidxtotal(e2,3)=e1;
   else
       Sixidxtotal(e2,5)=e1;
   end
end
%check if any crossings have been undone by the embedding
% Sixidxtotal
% pause
for i=Ndel1+1:N
    curre=incidentetotal(i);
    if Sixidxtotal(curre,1)==i
       nexte1=Sixidxtotal(curre,3); 
       nexte2=Sixidxtotal(curre,4); 
    else
       nexte1=Sixidxtotal(curre,5);
       nexte2=Sixidxtotal(curre,6);
    end
    if origedgelabel(curre)==origedgelabel(nexte1)
        %disp(['undo crossing ',num2str(origedgelabel(curre)), ' and ', num2str(origedgelabel(nexte2)),' \n'])
       %then crossing has been undone, so remove from clabel
       origclab(1:origcidx(Mdel1+1))
       for j=origcidx(origedgelabel(curre))+1:origcidx(origedgelabel(curre)+1)
           if origclab(j)==origedgelabel(nexte2)
              origclab(j)=[];
              planvlabels(j)=[];
              origcidx(origedgelabel(curre)+1:end)=origcidx(origedgelabel(curre)+1:end)-1;
              break;
           end
       end
       for j=origcidx(origedgelabel(nexte2))+1:origcidx(origedgelabel(nexte2)+1)
           if origclab(j)==origedgelabel(curre)
              origclab(j)=[];
              planvlabels(j)=[];
              origcidx(origedgelabel(nexte2)+1:end)=origcidx(origedgelabel(nexte2)+1:end)-1;
              break;
           end
       end

    elseif origedgelabel(curre)==origedgelabel(nexte2)
        %disp(['undo crossing ',num2str(origedgelabel(curre)), ' and ', num2str(origedgelabel(nexte1)),' \n'])
        %then crossing has been undone, so remove from clabel
       for j=origcidx(origedgelabel(curre))+1:origcidx(origedgelabel(curre)+1)
           origclab(j)
           if origclab(j)==origedgelabel(nexte1)
              origclab(j)=[];
              planvlabels(j)=[];
              origcidx(origedgelabel(curre)+1:end)=origcidx(origedgelabel(curre)+1:end)-1;
              break;
           end
       end
       for j=origcidx(origedgelabel(nexte1))+1:origcidx(origedgelabel(nexte1)+1)
           origclab(j)
           if origclab(j)==origedgelabel(curre)
              origclab(j)=[];
              planvlabels(j)=[];
              origcidx(origedgelabel(nexte1)+1:end)=origcidx(origedgelabel(nexte1)+1:end)-1;
              break;
           end
       end
    end
end
%make Dlabel
origdlab=zeros(origcidx(Mdel1+1),1);
for i=1:Mdel1
    for r=origcidx(i)+1:origcidx(i+1)
        if i<origclab(r)
            % for i=origN+1:N
            first=0;
            vert=planvlabels(r);
            oldv=vert;
            curre=incidentetotal(vert);
            starte=curre;
            for j=1:2
                if j==2
                    if Sixidxtotal(starte,1)==vert %these crossings must be correctly ordered.
                        starte=Sixidxtotal(starte,3);
                    else
                        starte=Sixidxtotal(starte,5);
                    end
                    curre=starte;
                    oldv=vert;
                end
                for k=1:M

                    if Sixidxtotal(curre,1)==oldv
                        oldv=Sixidxtotal(curre,2);
                    else
                        oldv=Sixidxtotal(curre,1);
                    end
%                                         oldv
%                     curre
%                     origedgelabel(curre)
%                     [i, origclab(r),j]
%                     Sixidxtotal(curre,:)
%                     disp('done')
                    if oldv<=Ndel1
                        oe=origedgelabel(curre,1);
                        if eldel1(oe,1)==oldv
                            %then we travelled to the small index
                            if first==1
                                %small,small clockwise.
                                for qq=origcidx(oefirst)+1:origcidx(oefirst+1)
                                    if origclab(qq)==oe
                                        origdlab(qq)=-1;
                                        break
                                    end
                                end
                                for qq=origcidx(oe)+1:origcidx(oe+1)
                                    if origclab(qq)==oefirst
                                        origdlab(qq)=1;
                                        break
                                    end
                                end
                                break
                            elseif first==2
                                %large,small clockwise.
                                for qq=origcidx(oefirst)+1:origcidx(oefirst+1)
                                    if origclab(qq)==oe
                                        origdlab(qq)=1;
                                        break
                                    end
                                end
                                for qq=origcidx(oe)+1:origcidx(oe+1)
                                    if origclab(qq)==oefirst
                                        origdlab(qq)=-1;
                                        break
                                    end
                                end
                                break
                            end
                            oefirst=oe;
                            first=1;
                            break;
                        else
                            %large index.
                            if first==1
                                %small,large clockwise.
                                for qq=origcidx(oefirst)+1:origcidx(oefirst+1)
                                    if origclab(qq)==oe
                                        origdlab(qq)=1;
                                        break
                                    end
                                end
                                for qq=origcidx(oe)+1:origcidx(oe+1)
                                    if origclab(qq)==oefirst
                                        origdlab(qq)=-1;
                                        break
                                    end
                                end
                                break
                            elseif first==2
                                %large,large clockwise.
                                for qq=origcidx(oefirst)+1:origcidx(oefirst+1)
                                    if origclab(qq)==oe
                                        origdlab(qq)=-1;
                                        break
                                    end
                                end
                                for qq=origcidx(oe)+1:origcidx(oe+1)
                                    if origclab(qq)==oefirst
                                        origdlab(qq)=1;
                                        break
                                    end
                                end
                                break
                            end
                            first=2;
                            oefirst=oe;
                            break;
                        end
                    end
                    if Sixidxtotal(curre,1)==oldv %need to move at least one step.
                        curre=Sixidxtotal(curre,3);
                    else
                        curre=Sixidxtotal(curre,5);
                    end
                    if origedgelabel(curre)~=origedgelabel(starte)
                        for qq=1:N
                            if origedgelabel(curre)==origedgelabel(starte)
                                break
                            end      
                            if Sixidxtotal(curre,1)==oldv
                                curre=Sixidxtotal(curre,3);
                            else
                                curre=Sixidxtotal(curre,5);
                            end
                        end
                    end
                end
            end
        end
    end
end
Sixidx2=zeros(Mdel1,6);
disp(['planar check']);
is_planar(sparse(el_to_adj(Sixidxtotal(:,1:2))))
pause
for i=1:Mdel1
    swap=0;
    if Sixidxtotal(i,1)<=Ndel1 && Sixidxtotal(i,2)>Ndel1
        ce=Sixidxtotal(i,5);
        ve=Sixidxtotal(i,2);
        if Sixidxtotal(ce,2)==ve
            ce=Sixidxtotal(ce,5);
        else
            ce=Sixidxtotal(ce,3);
        end
        if Sixidxtotal(ce,1)==ve
            ve=Sixidxtotal(ce,2);
        else
            ve=Sixidxtotal(ce,1);
        end
        for j=1:N
            if Sixidxtotal(ce,1)<=Ndel1
                break
            end
            if Sixidxtotal(ce,2)==ve
                ce=Sixidxtotal(ce,5);
            else
                ce=Sixidxtotal(ce,3);
            end
            if Sixidxtotal(ce,2)==ve
                ce=Sixidxtotal(ce,5);
            else
                ce=Sixidxtotal(ce,3);
            end
            if Sixidxtotal(ce,1)==ve
                ve=Sixidxtotal(ce,2);
            else
                ve=Sixidxtotal(ce,1);
            end
        end
        if Sixidxtotal(ce,1)<Sixidxtotal(i,1)
            swap=1;
        end
        if swap==0
            Sixidx2(i,1)=Sixidxtotal(i,1);
            Sixidx2(i,2)=Sixidxtotal(ce,1);
            Sixidx2(i,3)=origedgelabel(Sixidxtotal(i,3));
            Sixidx2(i,4)=origedgelabel(Sixidxtotal(i,4));
            Sixidx2(i,5)=origedgelabel(Sixidxtotal(ce,3));
            Sixidx2(i,6)=origedgelabel(Sixidxtotal(ce,4));
        else
            Sixidx2(i,1)=Sixidxtotal(ce,1);
            Sixidx2(i,2)=Sixidxtotal(i,1);
            Sixidx2(i,3)=origedgelabel(Sixidxtotal(ce,3));
            Sixidx2(i,4)=origedgelabel(Sixidxtotal(ce,4));
            Sixidx2(i,5)=origedgelabel(Sixidxtotal(i,3));
            Sixidx2(i,6)=origedgelabel(Sixidxtotal(i,4));
        end
    else
        Sixidx2(i,1)=Sixidxtotal(i,1);
        Sixidx2(i,2)=Sixidxtotal(i,2);
        Sixidx2(i,3)=origedgelabel(Sixidxtotal(i,3));
        Sixidx2(i,4)=origedgelabel(Sixidxtotal(i,4));
        Sixidx2(i,5)=origedgelabel(Sixidxtotal(i,5));
        Sixidx2(i,6)=origedgelabel(Sixidxtotal(i,6));
    end
    
    
end

%add back in degree one verts


end


