function [ cv,lin ] = embed_random_points( el,idxm,N,M,draw )
%A simple random geometric embedding of a graph into a plane
%vertices are randomly picked "squares" with the vertex in the middle and
%edges are linear lines between corresponding vertices.
%crossings are decided by intersecting lines  between the corresponding
%vertex co-ordinates.


restart = 1;
TOL=1e-4;
while(restart)
    
    restart = 0;
    
    blk=N^2;
    chkr=zeros(N);
    chkc=zeros(N);
    cv=zeros(N,2);
    
    
    for i=1:N  %% assigning unique coordinates to vertices
        t=1;
        while t>0
            x=round(rand(1)*(blk-1))+1;
            if chkr(x)==0
                t=0;
            end
        end
        chkr(x)=1;
        
        t=1;
        while t>0
            y=round(rand(1)*(blk-1))+1;
            if chkc(y)==0
                t=0;
            end
        end
        chkc(y)=1;
        
        cv(i,:)=[x,y];
    end
    
   
    
    lin=zeros(size(el,1),2);
    for i=1:M  %matrix with slope and y-intercept for each edge
        if cv(el(i,1),1)>cv(el(i,2),1)
            m=(cv(el(i,1),2)-cv(el(i,2),2))/(cv(el(i,1),1)-cv(el(i,2),1));
            c=cv(el(i,2),2)-m*cv(el(i,2),1);
            lin(i,:)=[m,c];
            
        else
            m=(cv(el(i,2),2)-cv(el(i,1),2))/(cv(el(i,2),1)-cv(el(i,1),1));
            c=cv(el(i,2),2)-m*cv(el(i,2),1);
            lin(i,:)=[m,c];
        end
    end
    
    for i=1:M
        for j=i+1:M
            if abs(lin(i,1)-lin(j,1))<TOL  && abs(lin(i,2)-lin(j,2))<TOL
                restart=1;
                break;
            end
        end
        if(restart)
            break;
        end
    end
    
    if(restart)
        continue;
    end
    
    isec=zeros(M*(M-1)/2,2);
    count=0;
    for i=1:M
        %    cvtemp=[];
        for j=i+1:M
            if el(j,1)~=el(i,1) && el(j,2)~=el(i,1) && el(j,1)~=el(i,2) && el(j,2)~=el(i,2)
                
                x=(lin(j,2)-lin(i,2))/(lin(i,1)-lin(j,1));
                y=lin(j,1)*x+lin(j,2);
                
                if x >= min([cv(el(i,1),1),cv(el(i,2),1)])-TOL && x <= max([cv(el(i,1),1),cv(el(i,2),1)])+TOL && y >= min([cv(el(i,1),2),cv(el(i,2),2)])-TOL && ... %write this smarter.
                        y <= max([cv(el(i,1),2),cv(el(i,2),2)])+TOL && x >= min([cv(el(j,1),1),cv(el(j,2),1)])-TOL && ...
                        x <= max([cv(el(j,1),1),cv(el(j,2),1)])+TOL && y >= min([cv(el(j,1),2),cv(el(j,2),2)])-TOL && y <= max([cv(el(j,1),2),cv(el(j,2),2)])+TOL
                    count=count+1;
                    isec(count,:)=[x,y];
                end
            end
        end
    end
    
    for i=1:count
        for j=i+1:count
            if (isec(i,1)-isec(j,1))^2+(isec(i,2)-isec(j,2))^2<TOL
                restart=1;
                break;
            end
        end
        if(restart)
            break;
        end
        for j=1:N
            if (isec(i,1)-cv(j,1))^2+(isec(i,2)-cv(j,2))^2<TOL
                restart=1;
            end
        end
        if(restart)
            break;
        end
    end
    
    
end
% then crossing found. so compute distance from crossing to

if draw %then plot output
stack=1:N;
while ~isempty(stack)
    i=stack(1);
    ck=1;


    for k=1:M
        if el(k,1)~=i && el(k,2)~=i



            for m=1:500
                yt2=lsp(k,m)*lin(k,1)+lin(k,2);
                if ((lsp(k,m)-cv(i,1))^2+(yt2-cv(i,2))^2)^(1/2)<4 || abs(cv(i,1)-cv(el(k,1),1))<1 || abs(cv(i,1)-cv(el(k,2),1))<1

                    %then move vert i
                    [cv,lin,lsp] = Move_vertex( cv,i,idxm(i,:),lin,blk,N,lsp );
                    ck=0;
                    stack=1:N;
                    %                                         clf
                    %                                         hold off
                    %                                         lsp2=linspace(0,50,1000);
                    %                                         plot(cv(:,1),cv(:,2),'o')
                    %                                         axis([0,blk,0,blk])
                    %                                         hold on
                    %                                         for q=1:15
                    %                                             elinesy=[];
                    %                                         for s=1:40
                    %                                             d=lsp(q,s)*lin(q,1)+lin(q,2);
                    %                                            elinesy=[elinesy,d];
                    %                                         end
                    %                                         plot(lsp(q,:),elinesy);
                    %                                         end
                    %                                         pause

                end
            end
        end
    end
    if ck==1;
        stack(1)=[];
    end
end


 lsp=[];
    for i=1:M  %% bunch of linear spaces for edge lines
        lsp(i,:)=linspace(min(cv(el(i,1),1),cv(el(i,2),1)),max(cv(el(i,1),1),cv(el(i,2),1)),500);
    end
                                                clf
                                        hold off
                                        lsp2=linspace(0,50,1000);
                                        plot(cv(:,1),cv(:,2),'o')
                                        axis([0,N^2,0,N^2])
                                        hold on
                                        for q=1:size(el,1)

                                            elinesy=[];
                                        for s=1:500

                                            d=lsp(q,s)*lin(q,1)+lin(q,2);


                                           elinesy=[elinesy,d];
                                        end
                                        plot(lsp(q,:),elinesy);
                                        end
                                        for q=1:N
                                            str=num2str(q);
                                            text(cv(q,1)+2,cv(q,2),str)
                                        end
end

end














