function [x,y] = kksl(el,vadj,vidx,k,l,seed)

do_draw = 0;
do_end_draw = 0;

N = max(max(el));

tolerance = 0.001/N;

if seed>0
   smap=randperm(N); 
else
   smap=1:N;
end
x = zeros(N,1);
y = zeros(N,1);
for i=1:N
    tt=2*pi*smap(i)/N;
    
    x(i) = l/2 + l/2*cos(tt/N);
    y(i) = l/2 + l/2*sin(tt/N);
end

if(do_draw)
    clf;
    hold on;
    axis([0 1.5*l 0 1.5*l]);
    plot(x,y,'x');
    for i=1:size(el,1)
        plot([x(el(i,1)) x(el(i,2))],[y(el(i,1)) y(el(i,2))],'k');
    end
end

D = zeros(N);
for i=1:N
    D(:,i) = sp_unweighted(vadj,vidx,i,N);
end
L = l/(max(max(D)))*D;
K = k./(D.^2);
T = zeros(N);
for i=1:N
    for j=i+1:N
        T(i,j) = (x(j)-x(i))^2 + (y(j)-y(i))^2;
        T(j,i) = T(i,j);
    end
end
par_x = zeros(N,1);
par_y = zeros(N,1);
Delta = zeros(N,1);
for m=1:N
    for i=1:N
        if(i == m)
            continue;
        end
        
        par_x(m) = par_x(m) + K(m,i)*((x(m) - x(i)) - L(m,i)*(x(m) - x(i))/sqrt((x(m)-x(i))^2 + (y(m)-y(i))^2));
        par_y(m) = par_y(m) + K(m,i)*((y(m) - y(i)) - L(m,i)*(y(m) - y(i))/sqrt((x(m)-x(i))^2 + (y(m)-y(i))^2));
    end
    Delta(m) = sqrt((par_x(m))^2 + (par_y(m))^2);
end
[a,m] = max(Delta);

prev_max_delta = 0;
count = 0;

while(count < 1000 && a > 1e-3 && abs(a - prev_max_delta)/prev_max_delta >= tolerance)
    count = count + 1;
    prev_max_delta = a;
   
    contributionx_m = zeros(N,1);
    contributiony_m = zeros(N,1);
    for i=1:N
        if(i == m)
            continue;
        end
        
        contributionx_m(i) = K(i,m)*((x(i) - x(m)) - L(i,m)*(x(i) - x(m))/sqrt(T(m,i)));
        contributiony_m(i) = K(i,m)*((y(i) - y(m)) - L(i,m)*(y(i) - y(m))/sqrt(T(m,i)));
    end
   
    first_time = 1;
    prev_inner_max_delta = 0;
    while(first_time || (Delta(m) > 1e-6 && (prev_inner_max_delta - Delta(m))/prev_inner_max_delta >= tolerance))
        prev_inner_max_delta = Delta(m);
        first_time = 0;
        C = -par_x(m);
        E = -par_y(m);
        
        F = 0;
        B = 0;
        D = 0;
        
        for i=1:N
            if(i == m)
                continue;
            end
            F = F + K(m,i)*(1 - L(m,i)*(y(m) - y(i))^2/(T(m,i))^(3/2));
            B = B + K(m,i)*(L(m,i)*(x(m) - x(i))*(y(m) - y(i))/(T(m,i))^(3/2));
            D = D + K(m,i)*(1 - L(m,i)*(x(m) - x(i))^2/(T(m,i))^(3/2));
        end
        %if count==2
        %disp('Fdone')
        %end
        delta_x = (C*D - E*B)/(F*D - B*B);
        delta_y = (E*F - B*C)/(F*D - B*B);
        qq=x(m);
        x(m) = x(m) + delta_x;
        y(m) = y(m) + delta_y;
% if count>45 && count<80
%     [x(33),delta_x,count]
% end
        %fprintf(1,[num2str(m) ' ' num2str(delta_x) ' ' num2str(delta_y) ' ' num2str(count) '\n'])
        for i=1:N
            if(i == m)
                continue;
            end
            
            T(i,m) = (x(m)-x(i))^2 + (y(m)-y(i))^2;
            T(m,i) = T(i,m);
        end
        
        par_x(m) = 0;
        par_y(m) = 0;
        for i=1:N
            if(i == m)
                continue;
            end
            
            par_x(m) = par_x(m) + K(m,i)*((x(m) - x(i)) - L(m,i)*(x(m) - x(i))/sqrt(T(m,i)));
            par_y(m) = par_y(m) + K(m,i)*((y(m) - y(i)) - L(m,i)*(y(m) - y(i))/sqrt(T(m,i)));
            
        end
        Delta(m) = sqrt((par_x(m))^2 + (par_y(m))^2);
    end
    
    for i=1:N
        if(i == m)
            continue;
        end
        
        par_x(i) = par_x(i) + K(i,m)*((x(i) - x(m)) - L(i,m)*(x(i) - x(m))/sqrt(T(m,i))) - contributionx_m(i);
        par_y(i) = par_y(i) + K(i,m)*((y(i) - y(m)) - L(i,m)*(y(i) - y(m))/sqrt(T(m,i))) - contributiony_m(i);
        Delta(i) = sqrt((par_x(i))^2 + (par_y(i))^2);
    end
    
    [a,m] = max(Delta);
    
    if(do_draw)
        clf;
        hold on;
        xt = x - min(x);
        yt = y - min(y);
        axis([0 1.5*l 0 1.5*l]);
        plot(xt,yt,'x');
        for i=1:size(el,1)
            plot([xt(el(i,1)) xt(el(i,2))],[yt(el(i,1)) yt(el(i,2))],'k');
        end
        pause(0.01)
    end
end
%x(33)
%pause
x = x - min(x);
y = y - min(y);



if(do_end_draw)
    clf;
    hold on;
    
    axis([min(x) max(x) min(y) max(y)]);
    for i=1:N
        text(x(i),y(i),num2str(i));
    end
    for i=1:size(el,1)
        plot([x(el(i,1)) x(el(i,2))],[y(el(i,1)) y(el(i,2))],'k');
    end
end
end
