function el = graph_el( A,b )
%Produces edgelist of desired graph
% Input A: Type;
% 1 = Complete Graph K_b
% 2 = Complete Bipartite Graph K_[b(1),b(2)]
% 3 = Generalized Petersen Graph GP(b(1),b(2))
% 4 = Complete Tripartite Graph K_[b(1),b(2),b(3)]
% 5 = Sheehan Maximally Uniquely Hamil. Graph S_b      
% 6 = Flower Snark I_b (b must be odd and >= 5)
% 7 = Hoffman singleton graph
% 8 = Petersen, 10 vertex, non-Hamiltonian cubic graph
% 9 = Heawood graph. Petersen graph with one vertex replaced by a triangle.
% 10 = Coxeter, 28 vertex, a minimal cubic graph with crossing number 11.
% 11 = b-dimensional cube graph.
% 12 = Moore graph with parameters b(1) and b(2).

if A==1
    el=adj_to_el(ones(b)-eye(b));
    return
end
if A==2
    el=adj_to_el([zeros(b(1)),ones(b(1),b(2));ones(b(2),b(1)),zeros(b(2))]);
    return
end
if A==3
    N = 2*b(1);
      M = 3*b(1);
      el = zeros(M,2);
      count = 1;
      for i=1:b(1)
         if(i ~= b(1))
            el(count,1) = i;
            el(count,2) = i+1;
            count=count+1;
         end
         if(i == 1)
            el(count,1) = 1;
            el(count,2) = b(1);
            count=count+1;
         end
         el(count,1) = i;
         el(count,2) = i+b(1);
         count=count+1;
      end
      
      for i=b(1)+1:2*b(1)
          if(i+b(2) <= N)
              el(count,1) = i;
              el(count,2) = i+b(2);
              count=count+1;
          end
          if(i-b(2) <= b(1))
              el(count,1) = i;
              el(count,2) = i-b(2)+b(1);
              count=count+1;
          end
      end

    return
end
if A==4
      M = b(1)*b(2) + b(1)*b(3) + b(2)*b(3);
      el = zeros(M,2);
      count = 1;
      for i=1:b(1)
         for j=1:b(2)
            el(count,1) = i;
            el(count,2) = b(1)+j;
            count=count+1;
         end
      end
      for i=1:b(1)
         for j=1:b(3)
            el(count,1) = i;
            el(count,2) = b(1)+b(2)+j;
            count=count+1;
         end
      end
      for i=1:b(2)
         for j=1:b(3)
            el(count,1) = b(1)+i;
            el(count,2) = b(1)+b(2)+j;
            count=count+1;
         end
      end
    return
end
if A==5
      N = b(1);
      M = floor(N*N/4) + 1;
      el = zeros(M,2);
   
      count = 1;
      for i=1:N-1
         if(mod(i,2) == 1)
            el(count,1) = i;
            el(count,2) = i+1;
            count=count+1;
         
            if(i == 1)
               el(count,1) = i;
               el(count,2) = N;
               count=count+1;
            end
         else
            for j=i+1:N
               el(count,1) = i;
               el(count,2) = j;
               count=count+1;
            end
         end
      end

    return
end
if A==6
    N = 4*b(1);
    M = 6*b(1);
    el = zeros(M,2);
      
      count = 1;
      for i=1:b(1)
         el(count,1) = 4*(i-1)+1;
         el(count,2) = 4*(i-1)+3;
         count=count+1;
      
         el(count,1) = 4*(i-1)+2;
         el(count,2) = 4*(i-1)+3;         
         count=count+1;
      
         el(count,1) = 4*(i-1)+3;
         el(count,2) = 4*(i-1)+4;         
         count=count+1;
      end
      
      for i=1:b(1)-1
         el(count,1) = 4*i;
         el(count,2) = 4*i + 4;
         count=count+1;
      end
      
      el(count,1) = 4;
      el(count,2) = 4*b(1);
      count=count+1;
      
      for i=1:b(1)-1

         el(count,1) = 4*i-3;
         el(count,2) = 4*i+1;
         count=count+1;
      end
      
      el(count,1) = 2;
      el(count,2) = 4*b(1)-3;
      count=count+1;
      
      for i=1:b(1)-1

         el(count,1) = 4*i-2;
         el(count,2) = 4*i+2;
         count=count+1;
      end
      
      el(count,1) = 1;
      el(count,2) = 4*b(1)-2;
    return
end
if A==7
N=[    0     1     1     1     1     1     1
0     2     2     2     2     2     2
0     3     3     3     3     3     3
0     4     4     4     4     4     4
0     5     5     5     5     5     5
0     6     6     6     6     6     6
1     0     2     3     4     5     6
2     0     1     4     5     6     3
3     0     5     1     6     4     2
4     0     6     2     1     3     5
5     0     3     6     2     1     4
6     0     4     5     3     2     1
1     2     0     6     3     4     5
2     1     0     5     6     3     4
3     5     0     4     1     2     6
4     6     0     3     5     1     2
5     3     0     2     4     6     1
6     4     0     1     2     5     3
1     3     6     0     5     2     4
2     4     5     0     3     1     6
3     1     4     0     2     6     5
4     2     3     0     6     5     1
5     6     2     0     1     4     3
6     5     1     0     4     3     2
1     4     3     5     0     6     2
2     5     6     3     0     4     1
3     6     1     2     0     5     4
4     1     5     6     0     2     3
5     2     4     1     0     3     6
6     3     2     4     0     1     5
1     5     4     2     6     0     3
2     6     3     1     4     0     5
3     4     2     6     5     0     1
4     3     1     5     2     0     6
5     1     6     4     3     0     2
6     2     5     3     1     0     4
1     6     5     4     2     3     0
2     3     4     6     1     5     0
3     2     6     5     4     1     0
4     5     2     1     3     6     0
5     4     1     3     6     2     0
6     1     3     2     5     4     0];
M=7;
A = zeros(N^2+1);

for i=1:N
    A(1,i+1) = 1; A(i+1,1) = 1;
end

for i=1:N
    for j=1:N-1
        A(i+1,N+1+(i-1)*(N-1)+j) = 1; A(N+1+(i-1)*(N-1)+j,i+1) = 1;
    end
end

for i=1:N
    for j=1:N-1
        for k=1:N
            if(M((i-1)*(N-1)+j,k) ~= 0)
                A(N+1+(i-1)*(N-1)+j,N+1+(k-1)*(N-1) + M((i-1)*(N-1)+j,k)) = 1;
                A(N+1+(k-1)*(N-1) + M((i-1)*(N-1)+j,k),N+1+(i-1)*(N-1)+j) = 1;
            end
        end
    end
end
    return
end
if A==8
el=[1 2;1 5;1 6;2 3;2 7;3 4;3 8;4 5;4 9;5 10;6 8;6 9;7 9;7 10;8 10];
    return
end
if A==9
el=[ 1     2;     1     6;     1    14;     2     3;     2    11;     3     4;     3     8;     4     5;     4    13;     5     6;     5    10;     6     7;     7     8;     7    12;     8     9;     9    10;     9    14;    10    11;    11    12;    12    13;    13    14];
    return
end
if A==10
el=[1 2;1 24;1 25;2 3;2 20;3 4;3 14;4 5;4 10;5 6;5 28;6 7;6 19;7 8;7 26;8 9;8 27;9 10;9 25;10 11;11 12;11 22;12 13;12 18;13 14;13 26;14 15;15 16;15 27;16 17;16 28;17 18;17 25;18 19;19 20;20 21;21 22;21 27;22 23;23 24;23 28;24 26];
    return
end
if A==11
    
    B=[0,1,0,1;
        1,0,1,0;
        0,1,0,1;
        1,0,1,0];
    for i=1:b-2
        k=size(B,1);
        B=[B,eye(k);eye(k),B];
    end
    el=adj_to_el(B);
    return
end

if A==12
    N=b(2);
    M=b(1);
    
   B = zeros(N^2+1);

for i=1:N
    B(1,i+1) = 1; B(i+1,1) = 1;
end

for i=1:N
    for j=1:N-1
        B(i+1,N+1+(i-1)*(N-1)+j) = 1; B(N+1+(i-1)*(N-1)+j,i+1) = 1;
    end
end

for i=1:N
    for j=1:N-1
        for k=1:N
            if(M((i-1)*(N-1)+j,k) ~= 0)
                B(N+1+(i-1)*(N-1)+j,N+1+(k-1)*(N-1) + M((i-1)*(N-1)+j,k)) = 1;
                B(N+1+(k-1)*(N-1) + M((i-1)*(N-1)+j,k),N+1+(i-1)*(N-1)+j) = 1;
            end
        end
    end
end 
    return
end
    

end

